==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Information/InfoArea/ts/InfoArea_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>InfoArea</name>
    <message>
        <location filename="../InfoArea.js" line="+65"/>
        <source>Set next polygon corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Definir canto polígono próxima</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Concluído
Cópias de segurança de desenhos não salvos foram feitas para os seguintes
lugares:\</translatorcomment>
        <translation>Concluído</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Polygon area:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Área do polígono:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translation>circunferência:</translation>
    </message>
    <message>
        <location filename="../InfoAreaInit.js" line="+2"/>
        <source>Pol&amp;ygonal Area</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Área pol&amp;igonal</translation>
    </message>
    <message>
        <location filename="../InfoArea.ui" line="+17"/>
        <source>Calculate length and close tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Calcular o comprimento e feche a ferramenta.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Close Tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Feche a ferramenta.</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Information/InfoArea/ts/InfoArea_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>InfoArea</name>
    <message>
        <location filename="../InfoArea.js" line="+70"/>
        <source>Set next polygon corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Defina o próximo vértice do polígono</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Concluído
Cópias de segurança de desenhos não salvos foram feitas para os seguintes
lugares:\</translatorcomment>
        <translation>Concluído</translation>
    </message>
    <message>
        <location line="+153"/>
        <source>Polygon area:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Área do polígono:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translation>circunferência:</translation>
    </message>
    <message>
        <location filename="../InfoAreaInit.js" line="+2"/>
        <source>Pol&amp;ygonal Area</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Área Pol&amp;igonal</translation>
    </message>
    <message>
        <location filename="../InfoArea.ui" line="+17"/>
        <source>Calculate length and close tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Calcule o comprimento e encerre a ferramenta.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Close Tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Encerre a Ferramenta.</translation>
    </message>
</context>
</TS>
